import { Language } from '../types'
import { readFileSync } from 'fs'
import { join } from 'path'
import { compile } from 'handlebars'

interface TemplateCache {
  [key: string]: {
    html: HandlebarsTemplateDelegate
    subject: HandlebarsTemplateDelegate,
    text: HandlebarsTemplateDelegate
  }
}

const templateCache: TemplateCache = {}

function loadTemplate(name: string, language: Language) {
  const cacheKey = `${name}:${language}`
  
  if (!templateCache[cacheKey]) {
    const htmlPath = join(process.cwd(), 'src', 'templates', name, `${language}.html`)
    const textPath = join(process.cwd(), 'src', 'templates', name, `${language}.txt`)
    const subjectPath = join(process.cwd(), 'src', 'templates', name, `${language}.subject.txt`)
    
    const htmlTemplate = readFileSync(htmlPath, 'utf-8')
    const textTemplate = readFileSync(textPath, 'utf-8')
    const subjectTemplate = readFileSync(subjectPath, 'utf-8')
    
    templateCache[cacheKey] = {
      html: compile(htmlTemplate),
      subject: compile(subjectTemplate),
      text: compile(textTemplate)
    }
  }
  
  return templateCache[cacheKey]
}

export function getEmailTemplate(name: string, language: Language) {
  const template = loadTemplate(name, language)
  
  return {
    subject: (data: any) => template.subject(data),
    html: (data: any) => template.html(data),
    text: (data: any) => template.text(data)
  }
}